# Copyright (C) 2024 Maxwell G <maxwell@gtmx.me>
# SPDX-License-Identifier: MIT
# License text: https://spdx.org/licenses/MIT

%bcond manpages 1
# Whether to build the scancode extra
%bcond scancode %[ %{defined fedora} && v"0%{?python3_version}" < v"3.14" ]
# Only run scancode tests (and install scancode at buildtime) when arch is not i386
%bcond scancode_tests %[ %{with scancode} && "%{_arch}" != "i386"]

%global forgeurl https://gitlab.com/fedora/sigs/go/go-vendor-tools
%define tag v%{version_no_tilde %{quote:%nil}}

Name:           go-vendor-tools
Version:        0.7.0^34.20250627.b68caa5
%forgemeta
Release:        1%{?dist}
Summary:        Tools for handling Go library vendoring in Fedora [SEE NOTE IN DESCRIPTION]

# BSD-3-Clause: src/go_vendor_tools/archive.py
License:        MIT AND BSD-3-Clause
URL:            %{forgeurl}
Source0:        go-vendor-tools-0.7.0^34.20250627.b68caa5.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

# Test dependencies
BuildRequires:  askalono-cli
BuildRequires:  trivy

%if %{with manpages}
BuildRequires:  scdoc
%endif

# First choice backend
Recommends:     askalono-cli
# Used by default for go_vendor_license report --autofill
Recommends:     go-vendor-tools+scancode
Recommends:     go-vendor-tools+all


%global common_description %{expand:
go-vendor-tools provides tools and macros for handling Go library vendoring in
Fedora.

STABILITY NOTE:

go-vendor-tools is under active development and available in the stable Fedora
and Fedora EPEL repos for testing purposes.
Expect some breaking changes between releases.
Anyone using the `%%go_vendor_*` macros in active Fedora packages MUST join the
Fedora Golang Matrix room and Fedora Go SIG mailing list to be notified of any
major changes.}

%description %common_description


%package doc
Summary:        Documentation for go-vendor-tools
Enhances:       go-vendor-tools

%description doc %common_description


%prep
%autosetup -p1 


%generate_buildrequires
%pyproject_buildrequires -x all,test%{?with_scancode_tests:,scancode}


%build
%pyproject_wheel
%if %{with manpages}
./doc/man/mkman.sh
%endif

mkdir -p bash_completions fish_completions zsh_completions
for bin in go_vendor_archive go_vendor_license; do
    register-python-argcomplete --shell bash "${bin}" > "bash_completions/${bin}"
    register-python-argcomplete --shell fish "${bin}" > "fish_completions/${bin}.fish"
    # Compatibility with old argcomplete versions
    if ! (register-python-argcomplete --shell zsh "${bin}" > "zsh_completions/_${bin}"); then
        echo "#compdef ${bin}" > "zsh_completions/_${bin}"
        echo -e "autoload -Uz bashcompinit\nbashcompinit" > "zsh_completions/_${bin}"
        cat "bash_completions/${bin}" >> "zsh_completions/_${bin}"
    fi
done


%install
%pyproject_install
# TODO(anyone): Use -l flag once supported by EL 9.
%pyproject_save_files go_vendor_tools

# Install RPM macros
install -Dpm 0644 rpm/macros.go_vendor_tools -t %{buildroot}%{_rpmmacrodir}

# Install documentation
mkdir -p %{buildroot}%{_docdir}/go-vendor-tools-doc
cp -rL doc/* %{buildroot}%{_docdir}/go-vendor-tools-doc

# Install manpages
%if %{with manpages}
install -Dpm 0644 doc/man/*.1 -t %{buildroot}%{_mandir}/man1/
install -Dpm 0644 doc/man/*.5 -t %{buildroot}%{_mandir}/man5/
%endif

# Install completions
install -Dpm 0644 bash_completions/* -t %{buildroot}%{bash_completions_dir}/
install -Dpm 0644 fish_completions/* -t %{buildroot}%{fish_completions_dir}/
install -Dpm 0644 zsh_completions/* -t %{buildroot}%{zsh_completions_dir}/


%check
export MACRO_DIR=%{buildroot}%{_rpmmacrodir}
%pytest


%files -f %{pyproject_files}
# Install top-level markdown files
%doc *.md
%license LICENSES/*
%{_bindir}/go_vendor*
%{bash_completions_dir}/go_vendor_*
%{fish_completions_dir}/go_vendor_*.fish
%{zsh_completions_dir}/_go_vendor_*
%{_rpmmacrodir}/macros.go_vendor_tools
%if %{with manpages}
%{_mandir}/man1/go*.1*
%{_mandir}/man5/go*.5*
%endif

%files doc
%doc %{_docdir}/go-vendor-tools-doc/

%pyproject_extras_subpkg -n go-vendor-tools all %{?with_scancode:scancode}

%changelog
* Fri Jun 27 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^34.20250627.b68caa5-1
- license: don't include notice.go files

* Fri Jun 27 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^33.20250627.347aac3-1
- lint: fix more errors

* Fri Jun 27 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^32.20250627.b17f9e3-1
- rpm: include full license breakdown in macro

* Fri Jun 27 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^31.20250627.a7f3052-1
- license: improve handling of invalid license keys

* Fri Jun 27 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^30.20250627.814a366-1
- tests integration: disable scancode on py3.14

* Fri Jun 27 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^29.20250627.b638b4b-1
- tests: update comment

* Fri Jun 27 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^28.20250627.5b370ca-1
- Support $NO_COLOR and $FORCE_COLOR standards

* Mon Jun 16 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^27.20250616.a8f1014-1
- packaging: temporarily disable scancode on py3.14

* Mon Jun 16 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^26.20250616.014bf70-1
- archive: include go.mod and go.sum in go.work mode

* Mon Jun 16 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^25.20250616.0d2508e-1
- Add support for non-root level go.mod paths

* Wed Jun 11 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^24.20250611.76649fb-1
- tests integration: check REUSE support

* Mon Jun 02 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^23.20250602.890edaa-1
- doc README: go-vendor-tools -> Go Vendor Tools

* Mon Jun 02 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^22.20250602.c577233-1
- license_detection: actually make askalono the default

* Mon Jun 02 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^21.20250602.ab0d79e-1
- cli license: fix autofill detector selection bugs

* Mon Jun 02 2025 Nils Philippsen <nils@tiptoe.de> - 0.7.0^20.20250602.cdccc72-1
- scancode: cope if license_expression_spdx is None

* Sun May 25 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^19.20250525.55d897f-1
- ci packit: use wait-for-copr from pip

* Sat May 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^18.20250524.84d6312-1
- specfile: fix typing error with latest scancode

* Sat May 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^17.20250524.d384810-1
- mkdocs: fix incorrect nav entry

* Sat May 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^16.20250524.6e94d9f-1
- packaging: add Recommends for askalono and scancode

* Tue Apr 08 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^15.20250408.6e68f37-1
- licenses: update --autofill help message

* Tue Apr 01 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^14.20250401.e5c95b7-1
- lint pyright: update to 3.10 for new specfile stubs

* Tue Apr 01 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^13.20250401.5346821-1
- tests: add initial get_missing_licenses tests

* Tue Apr 01 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^12.20250401.6790105-1
- license_detection: document backends and make askalono default

* Tue Apr 01 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^11.20250401.a633917-1
- cli license: implement --autofill functionality

* Tue Apr 01 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^10.20250401.6e09284-1
- licensing combine_licenses: use recursive_simplify by default

* Tue Apr 01 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^9.20250401.6f90ca6-1
- lint pyright: lower reportPossiblyUnboundVariable severity

* Tue Apr 01 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^8.20250401.25e3c19-1
- license_detection search: include "Li[cs]ense.*" glob

* Mon Mar 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^7.20250324.871161e-1
- lint pyright: update config

* Mon Mar 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^6.20250324.1825551-1
- Revert "nox: use requires for lint sessions"

* Mon Mar 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^5.20250324.3f85d60-1
- internal LicenseDetector: add detect_files method

* Mon Mar 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^4.20250324.63c1436-1
- nox: use requires for lint sessions

* Mon Mar 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^3.20250324.cd4b287-1
- tests: test manual license entries

* Mon Mar 24 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^2.20250324.47d53ed-1
- internal license_detection: cleanup design of LicenseData class

* Sun Mar 23 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0^1.20250323.b60df4f-1
- Post-release version bump

* Sun Mar 23 2025 Maxwell G <maxwell@gtmx.me> - 0.7.0-1
- Release 0.7.0.

* Wed Aug 28 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0-1
- Release 0.6.0.

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1-1
- Release 0.5.1.

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.0-1
- Release 0.5.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0-1
- Release 0.4.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0~b1-1
- Release 0.4.0b1.

* Thu Mar 28 2024 Maxwell G <maxwell@gtmx.me> - 0.3.0-1
- Release 0.3.0.

* Sat Mar 16 2024 Maxwell G <maxwell@gtmx.me> - 0.2.0-1
- Release 0.2.0.

* Sat Mar 09 2024 Maxwell G <maxwell@gtmx.me> - 0.1.0-1
- Release 0.1.0.

* Tue Mar 05 2024 Maxwell G <maxwell@gtmx.me> - 0.0.1-1
- Release 0.0.1.
